def Hello_world():
    return "hello, world"


if __name__ == '__main__':
    str = Hello_world()
    print(str)
